@@ -1,7 +1,7 @@
 #
 # linim.R
 #
-#  $Revision: 1.83 $   $Date: 2023/01/15 10:31:26 $
+#  $Revision: 1.86 $   $Date: 2025/06/14 03:35:24 $
 #
 #  Image/function on a linear network
 #
@@ -30,7 +30,7 @@ linim <- function(L, Z, ..., restrict=TRUE, df=NULL) {
   }
   if(restrict) {
     #' restrict image to pixels actually lying on the network
-    M <- as.mask.psp(as.psp(L), Z)
+    M <- psp2mask(as.psp(L), Z)
     if(dfgiven) {
       #' ensure all mapped pixels are untouched
       pos <- nearest.pixel(df$xc, df$yc, Z)
@@ -190,7 +190,7 @@ plot.linim <- local({
         #' first fatten the lines 
         L <- attr(x, "L")
         S <- as.psp(L)
-        D <- distmap(as.mask.psp(S, xy=x))
+        D <- distmap(psp2mask(S, xy=x))
         fatwin <- levelset(D, fatten)
         x <- nearestValue(x)[fatwin, drop=FALSE]
       }
@@ -367,10 +367,13 @@ as.linim <- function(X, ...) {
 }
 
 as.linim.default <- function(X, L, ..., eps = NULL, dimyx = NULL, xy = NULL,
-                                        delta = NULL, nd = NULL) {
+                             rule.eps=c("adjust.eps",
+                                        "grow.frame", "shrink.frame"),
+                             delta = NULL, nd = NULL) {
   stopifnot(inherits(L, "linnet"))
-  Y <- as.im(X, W=Frame(L), ..., eps=eps, dimyx=dimyx, xy=xy)
-  M <- as.mask.psp(as.psp(L), as.owin(Y))
+  rule.eps <- match.arg(rule.eps)
+  Y <- as.im(X, W=Frame(L), ..., eps=eps, dimyx=dimyx, xy=xy, rule.eps=rule.eps)
+  M <- psp2mask(as.psp(L), as.owin(Y))
   Y[complement.owin(M)] <- NA
   df <- NULL
   if(!is.null(delta) || !is.null(nd)) {
@@ -383,8 +386,10 @@ as.linim.default <- function(X, L, ..., eps = NULL, dimyx = NULL, xy = NULL,
     df <- df[,c("xc", "yc", "x", "y", "seg", "tp", "values")]
     names(df)[names(df) == "seg"] <- "mapXY"
   }
-  if(is.mask(WL <- Window(L)) && !all(sapply(list(eps, dimyx, xy), is.null)))
-     Window(L, check=FALSE) <- as.mask(WL, eps=eps, dimyx=dimyx, xy=xy)
+  if(is.mask(WL <- Window(L)) && !all(sapply(list(eps, dimyx, xy), is.null))) {
+    Window(L, check=FALSE) <- as.mask(WL,
+                              eps=eps, dimyx=dimyx, xy=xy, rule.eps=rule.eps)
+  }
   out <- linim(L, Y, df=df, restrict=FALSE)
   return(out)
 }
@@ -590,7 +595,7 @@ as.linnet.linim <- function(X, ...) {
   changed <- (okx != oky) | (okx & oky & yvalue != xvalue)
   df$values[changed] <- yvalue[changed]
   #' restrict main pixel image to network
-  m <- as.mask.psp(L, as.mask(y))$m
+  m <- psp2mask(L, as.mask(y))$m
   m[pos] <- TRUE
   y$v[!m] <- NA
   #' package up
@@ -674,7 +679,12 @@ quantile.linim <- function(x, probs = seq(0,1,0.25), ...) {
   len <- lengths_psp(as.psp(L))
   iseg <- as.integer(seg)
   wts <- len[iseg]/nvals[iseg]
-  return(weighted.quantile(vals, wts, probs))
+  #' quantiles
+  result <- do.call(weighted.quantile,
+                    resolve.defaults(list(x=vals, w=wts, probs=probs),
+                                     list(...),
+                                     list(type=4, collapse=FALSE)))
+  return(result)
 }
 
 quantilefun.linim <- function(x, ..., type=1) {
